Documentation
¶
Overview ¶
Package bumper is a generated GoMock package.
Index ¶
Constants ¶
const (
// MatchField is the index to get the first capture group, aka the field (major, minor, etc.)
MatchField = 1
)
Variables ¶
var DefaultSet = wire.NewSet(wire.Struct(new(DefaultBumper), "*"), wire.Bind(new(Bumper), new(*DefaultBumper)))
var ErrInvalidField = fmt.Errorf("not a valid Field, try [%s]", strings.Join(_FieldNames, ", "))
Functions ¶
func FieldNames ¶
func FieldNames() []string
FieldNames returns a list of possible string values of Field.
Types ¶
type BumpOption ¶
type BumpOption func(*bumpOptions)
func WithDryRun ¶
func WithDryRun(dryrun bool) BumpOption
func WithField ¶
func WithField(field Field) BumpOption
func WithMerged ¶
func WithMerged(merged bool) BumpOption
func WithPrefix ¶
func WithPrefix(prefix string) BumpOption
type Bumper ¶
type DefaultBumper ¶
func (*DefaultBumper) Bump ¶
func (d *DefaultBumper) Bump(options ...BumpOption) error
func (*DefaultBumper) LatestVersion ¶
type Field ¶
type Field string
Field ENUM(auto, major, minor, patch, prerelease)
const ( // FieldAuto is a Field of type auto. FieldAuto Field = "auto" // FieldMajor is a Field of type major. FieldMajor Field = "major" // FieldMinor is a Field of type minor. FieldMinor Field = "minor" // FieldPatch is a Field of type patch. FieldPatch Field = "patch" // FieldPrerelease is a Field of type prerelease. FieldPrerelease Field = "prerelease" )
func ParseField ¶
ParseField attempts to convert a string to a Field.
func (Field) MarshalText ¶
MarshalText implements the text marshaller method.
func (*Field) UnmarshalText ¶
UnmarshalText implements the text unmarshaller method.
type MockBumper ¶
type MockBumper struct {
// contains filtered or unexported fields
}
MockBumper is a mock of Bumper interface.
func NewMockBumper ¶
func NewMockBumper(ctrl *gomock.Controller) *MockBumper
NewMockBumper creates a new mock instance.
func (*MockBumper) Bump ¶
func (m *MockBumper) Bump(arg0 ...BumpOption) error
Bump mocks base method.
func (*MockBumper) EXPECT ¶
func (m *MockBumper) EXPECT() *MockBumperMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockBumperMockRecorder ¶
type MockBumperMockRecorder struct {
// contains filtered or unexported fields
}
MockBumperMockRecorder is the mock recorder for MockBumper.
func (*MockBumperMockRecorder) Bump ¶
func (mr *MockBumperMockRecorder) Bump(arg0 ...interface{}) *gomock.Call
Bump indicates an expected call of Bump.
Click to show internal directories.
Click to hide internal directories.